library(testthat)
library(BEKKs)

test_check("BEKKs")
